@@ -6,7 +6,7 @@ use warnings;
 
 =head1 NAME
 
-Device::FTDI - perl extension to talk to FTDI chips
+C<Device::FTDI> - use USB-attached serial interface chips from I<FTDI>.
 
 =head1 VERSION
 
@@ -14,7 +14,7 @@ Version 0.06
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 
@@ -57,30 +57,68 @@ our @EXPORT_OK = qw(
     BITMODE_SYNCFF
 );
 
-our %EXPORT_TAGS = (all => \@EXPORT_OK);
+# More constants
+my %USB_IDS;
+BEGIN {
+    %USB_IDS = (
+        VID_FTDI => 0x0403,
+
+        # https://usb-ids.gowdy.us/read/UD/0403 is useful
+        PID_FT232   => 0x6001,
+        PID_FT2232C => 0x6010,
+        PID_FT4232H => 0x6011,
+        PID_FT232H  => 0x6014,
+    );
+
+    require constant;
+    constant->import( \%USB_IDS );
+}
+push @EXPORT_OK, keys %USB_IDS;
+
+our %EXPORT_TAGS = (
+    all => \@EXPORT_OK,
+
+    flow      => [ grep { m/^FLOW_/      } @EXPORT_OK ],
+    bits      => [ grep { m/^BITS_/      } @EXPORT_OK ],
+    stop      => [ grep { m/^STOP_/      } @EXPORT_OK ],
+    parity    => [ grep { m/^PARITY_/    } @EXPORT_OK ],
+    break     => [ grep { m/^BREAK_/     } @EXPORT_OK ],
+    interface => [ grep { m/^INTERFACE_/ } @EXPORT_OK ],
+    bitmode   => [ grep { m/^BITMODE_/   } @EXPORT_OK ],
+
+    vid => [ grep { m/^VID_/ } @EXPORT_OK ],
+    pid => [ grep { m/^PID_/ } @EXPORT_OK ],
+);
 
 require XSLoader;
 XSLoader::load('Device::FTDI', $VERSION);
 
 =head1 SYNOPSIS
 
-    use Device::FTDI;
+    use Device::FTDI qw( :bits :stop :parity :break :bitmode );
 
     my $dev = Device::FTDI->new();
-    ...
+    $dev->reset;
+
+    $dev->set_baudrate( 57600 );
+    $dev->set_line_property( BITS_8, STOP_BIT_1, PARITY_NONE, BREAK_OFF );
+
+    $dev->write_data( "Hello, world!\n" );
 
 =head1 DESCRIPTION
 
 B<WARNING:> this is an alpha version
 
-This is Perl bindings to libftdi library. It allows you to communicate with
-FTDI chips supported by this library.
+This is Perl bindings to F<libftdi> library. It allows you to communicate with
+I<FTDI> chips supported by this library.
 
 =head1 CLASS METHODS
 
 =cut
 
-=head2 $class->find_all(%params)
+=head2 find_all
+
+    $class->find_all(%params)
 
 Finds all connected devices with specified vendor and product codes. Returns
 list of hashes describing devices. Following parameters are accepted:
@@ -89,11 +127,11 @@ list of hashes describing devices. Following parameters are accepted:
 
 =item B<vendor>
 
-vendor code. Default 0x0403.
+vendor code. Default C<0x0403>.
 
 =item B<product>
 
-product code. Default 0x6001.
+product code. Default C<0x6001>.
 
 =back
 
@@ -101,26 +139,28 @@ product code. Default 0x6001.
 
 sub find_all {
     my ($class, %params) = @_;
-    $params{vendor} ||= 0x0403;
-    $params{product} ||= 0x6001;
+    $params{vendor}  ||= VID_FTDI;
+    $params{product} ||= PID_FT232;
     my @list = _find_all($params{vendor}, $params{product});
     return map { bless $_, 'Device::FTDI::Description' } @list;
 }
 
-=head2 $class->new(%params)
+=head2 new
 
-Opens specified device and returns the corresponding object refference. Dies if
+    $class->new(%params)
+
+Opens specified device and returns the corresponding object reference. Dies if
 an attempt to open the device has failed. Accepts following parameters:
 
 =over 4
 
 =item B<vendor>
 
-vendor code. Default 0x0403.
+vendor code. Default C<0x0403>.
 
 =item B<product>
 
-product code. Default 0x6001.
+product code. Default C<0x6001>.
 
 =item B<description>
 
@@ -140,13 +180,26 @@ device index. By default 0.
 
 sub new {
     my ($class, %params) = @_;
-    $params{vendor} ||= 0x0403;
-    $params{product} ||= 0x6001;
+    $params{vendor}  ||= VID_FTDI;
+    $params{product} ||= PID_FT232;
     $params{index} ||= 0;
     my $dev = _open_device($params{vendor}, $params{product}, $params{description}, $params{serial}, $params{index});
     return bless { _ctx => $dev }, $class;
 }
 
+=pod
+
+In either case, the following constants may be used to specify C<vendor> or
+C<product>:
+
+    VID_FTDI
+
+(export tag C<:vid>)
+
+    PID_FT232, PID_FT2232C, PID_FT4232H, PID_FT232H
+
+(export tag C<:pid>)
+
 =head1 DEVICE METHODS
 
 Most of device methods return negative value in case of error. You can get
@@ -154,8 +207,9 @@ error description using L</error_string> method.
 
 =cut
 
-=head2 $dev->error_string
-X<error_string>
+=head2 error_string
+
+    $dev->error_string
 
 Returns string describing error after last operation
 
@@ -165,7 +219,9 @@ sub error_string {
     return _error_string( shift->{_ctx} );
 }
 
-=head2 $dev->reset
+=head2 reset
+
+    $dev->reset
 
 Resets the device
 
@@ -175,10 +231,16 @@ sub reset {
     return _reset(shift->{_ctx});
 }
 
-=head2 set_interface($interface)
+=head2 set_interface
 
-Open selected channels on a chip, otherwise use first channel. I<$interface> may be one of:
-C<INTERFACE_A>, C<INTERFACE_B>, C<INTERFACE_C>, C<INTERFACE_D>, or C<INTERFACE_ANY>.
+    $dev->set_interface($interface)
+
+Open selected channels on a chip, otherwise use first channel. I<$interface> may
+be one of:
+
+    INTERFACE_A, INTERFACE_B, INTERFACE_C, INTERFACE_D, INTERFACE_ANY
+
+(export tag C<:interface>)
 
 =cut
 
@@ -187,10 +249,12 @@ sub set_interface {
     return _set_interface( $self->{_ctx}, $interface );
 }
 
-=head2 $dev->purge_rx_buffer
+=head2 purge_rx_buffer
 
-Clears the read buffer on the chip and the internal read buffer.
-Returns 0 on success or negative error code otherwise.
+    $dev->purge_rx_buffer
+
+Clears the read buffer on the chip and the internal read buffer. Returns 0 on
+success or negative error code otherwise.
 
 =cut
 
@@ -198,10 +262,12 @@ sub purge_rx_buffer {
     return _purge_rx_buffer(shift->{_ctx});
 }
 
-=head2 $dev->purge_tx_buffer
+=head2 purge_tx_buffer
 
-Clears the write buffer on the chip.
-Returns 0 on success or negative error code otherwise.
+    $dev->purge_tx_buffer
+
+Clears the write buffer on the chip. Returns 0 on success or negative error
+code otherwise.
 
 =cut
 
@@ -209,10 +275,12 @@ sub purge_tx_buffer {
     return _purge_tx_buffer(shift->{_ctx});
 }
 
-=head2 $dev->purge_buffers
+=head2 purge_buffers
 
-Clears the buffers on the chip and the internal read buffer.
-Returns 0 on success or negative error code otherwise.
+    $dev->purge_buffers
+
+Clears the buffers on the chip and the internal read buffer. Returns 0 on
+success or negative error code otherwise.
 
 =cut
 
@@ -220,20 +288,34 @@ sub purge_buffers {
     return _purge_buffers(shift->{_ctx});
 }
 
-=head2 $dev->setflowctrl($flowctrl)
+=head2 set_flow_control
+
+    $dev->set_flow_control($flowctrl)
+
+I<Since version 0.07>.
 
 Set flow control for ftdi chip. Allowed values for I<$flowctrl> are:
-FLOW_RTS_CTS, FLOW_DTR_DSR, FLOW_XON_XOFF, FLOW_DISABLE.
+
+    FLOW_RTS_CTS, FLOW_DTR_DSR, FLOW_XON_XOFF, FLOW_DISABLE
+
+(export tag C<:flow>)
+
 Returns 0 on success or negative error code otherwise.
 
+This method is also available aliased as C<setflowctrl> for back-compatibility
+and to match the name used by F<libftdi> itself.
+
 =cut
 
-sub setflowctrl {
+sub set_flow_control {
     my ( $self, $flowctrl ) = @_;
     return _setflowctrl( $self->{_ctx}, $flowctrl );
 }
+*setflowctrl = \&set_flow_control;
 
-=head2 $dev->set_line_property($bits, $stop_bit, $parity, $break)
+=head2 set_line_property
+
+    $dev->set_line_property($bits, $stop_bit, $parity, $break)
 
 Sets line characteristics. Last parameters may be ommited. Following values are
 acceptable for parameters (* marks default value):
@@ -242,24 +324,32 @@ acceptable for parameters (* marks default value):
 
 =item B<$bits>
 
-C<BITS_7>, C<BITS_8> (*)
+    BITS_7, BITS_8 (*)
+
+(export tag C<:bits>)
 
 =item B<$stop_bit>
 
-C<STOP_BIT_1>, C<STOP_BIT_2>, C<STOP_BIT_15> (*)
+    STOP_BIT_1, STOP_BIT_2, STOP_BIT_15 (*)
+
+(export tag C<:stop>)
 
 =item B<$parity>
 
-C<PARITY_NONE> (*), C<PARITY_EVEN>, C<PARITY_ODD>, C<PARITY_MARK>, C<PARITY_SPACE>
+    PARITY_NONE (*), PARITY_EVEN, PARITY_ODD, PARITY_MARK, PARITY_SPACE
+
+(export tag C<:parity>)
 
 =item B<$parity>
 
-C<BREAK_OFF> (*), C<BREAK_ON>
+    BREAK_OFF (*), BREAK_ON
+
+(export tag C<:break>)
 
 =back
 
-Note, that you have to import constants you need. You can import all constants
-using C<:all> tag.
+Note that you have to import constants you need. You can import all constants
+using C<:all> tag, or individual groups using the other named tags.
 
 Returns 0 on success or negative error code otherwise.
 
@@ -275,10 +365,11 @@ sub set_line_property {
     return _set_line_property2( $self->{_ctx}, $bits, $stop_bit, $parity, $break );
 }
 
-=head2 $dev->set_baudrate($baudrate)
+=head2 set_baudrate
 
-Sets the chip baudrate.
-Returns 0 on success or negative error code otherwise.
+    $dev->set_baudrate($baudrate)
+
+Sets the chip baudrate. Returns 0 on success or negative error code otherwise.
 
 =cut
 
@@ -287,11 +378,13 @@ sub set_baudrate {
     return _set_baudrate($self->{_ctx}, $baudrate);
 }
 
-=head2 $dev->set_latency_timer($latency)
+=head2 set_latency_timer
 
-Sets latency timer. The FTDI chip keeps data in the internal buffer for a
+    $dev->set_latency_timer($latency)
+
+Sets latency timer. The I<FTDI> chip keeps data in the internal buffer for a
 specific amount of time if the buffer is not full yet to decrease load on the
-usb bus. Latency must be between 1 and 255.
+USB bus. Latency must be between 1 and 255.
 
 Returns 0 on success or negative error code otherwise.
 
@@ -303,7 +396,9 @@ sub set_latency_timer {
     return _set_latency_timer( $self->{_ctx}, $latency );
 }
 
-=head2 $dev->get_latency_timer
+=head2 get_latency_timer
+
+    $dev->get_latency_timer
 
 Returns latency timer value or negative error code.
 
@@ -313,10 +408,12 @@ sub get_latency_timer {
     return _get_latency_timer( shift->{_ctx} );
 }
 
-=head2 $dev->write_data_set_chunksize($chunksize)
+=head2 write_data_set_chunksize
 
-Sets write buffer chunk size. Default 4096.
-Returns 0 on success or negative error code otherwise.
+    $dev->write_data_set_chunksize($chunksize)
+
+Sets write buffer chunk size. Default C<4096>. Returns 0 on success or
+negative error code otherwise.
 
 =cut
 
@@ -325,7 +422,9 @@ sub write_data_set_chunksize {
     return _write_data_set_chunksize( $self->{_ctx}, $chunksize );
 }
 
-=head2 $dev->write_data_get_chunksize
+=head2 write_data_get_chunksize
+
+    $dev->write_data_get_chunksize
 
 Returns write buffer chunk size or negative error code.
 
@@ -335,10 +434,12 @@ sub write_data_get_chunksize {
     return _write_data_get_chunksize( shift->{_ctx} );
 }
 
-=head2 $dev->read_data_set_chunksize($chunksize)
+=head2 read_data_set_chunksize
 
-Sets read buffer chunk size. Default 4096.
-Returns 0 on success or negative error code otherwise.
+    $dev->read_data_set_chunksize($chunksize)
+
+Sets read buffer chunk size. Default 4096. Returns 0 on success or negative
+error code otherwise.
 
 =cut
 
@@ -347,7 +448,9 @@ sub read_data_set_chunksize {
     return _read_data_set_chunksize( $self->{_ctx}, $chunksize );
 }
 
-=head2 $dev->read_data_get_chunksize
+=head2 read_data_get_chunksize
+
+    $dev->read_data_get_chunksize
 
 Returns read buffer chunk size or negative error code.
 
@@ -357,10 +460,12 @@ sub read_data_get_chunksize {
     return _read_data_get_chunksize( shift->{_ctx} );
 }
 
-=head2 $dev->write_data($data)
+=head2 write_data
 
-Writes data to the chip in chunks.
-Returns number of bytes written on success or negative error code otherwise.
+    $dev->write_data($data)
+
+Writes data to the chip in chunks. Returns number of bytes written on success
+or negative error code otherwise.
 
 =cut
 
@@ -369,7 +474,9 @@ sub write_data {
     return _write_data( $self->{_ctx}, $data );
 }
 
-=head2 $dev->read_data($buffer, $size)
+=head2 read_data
+
+    $dev->read_data($buffer, $size)
 
 Reads data from the chip (up to I<$size> bytes) and stores it in I<$buffer>.
 Returns when at least one byte is available or when the latency timer has
@@ -386,12 +493,17 @@ sub read_data {
     return _read_data( $self->{_ctx}, $_[1], $size);
 }
 
-=head2 $dev->set_bitmode($mask, $mode)
+=head2 set_bitmode
+
+    $dev->set_bitmode($mask, $mode)
 
 Enable/disable bitbang modes. I<$mask> -- bitmask to configure lines, High/ON
 value configures a line as output. I<$mode> may be one of the following:
-C<BITMODE_RESET>, C<BITMODE_BITBANG>, C<BITMODE_MPSSE>, C<BITMODE_SYNCBB>,
-C<BITMODE_MCU>, C<BITMODE_OPTO>, C<BITMODE_CBUS>, C<BITMODE_SYNCFF>.
+
+    BITMODE_RESET, BITMODE_BITBANG, BITMODE_MPSSE, BITMODE_SYNCBB,
+    BITMODE_MCU, BITMODE_OPTO, BITMODE_CBUS, BITMODE_SYNCFF.
+
+(export tag C<:bitmode>)
 
 =cut
 
@@ -418,14 +530,17 @@ L<http://www.intra2net.com/en/developer/libftdi/>
 
 Pavel Shaydo, C<< <zwon at cpan.org> >>
 
+Maintained since 2015 by Paul Evans <leonerd@leonerd.org.uk>
+
 =head1 BUGS
 
 Please report any bugs or feature requests via GitHub bugtracker for this project:
-L<https://github.com/trinitum/perl-Device-FTDI/issues>.
+L<https://github.com/leonerd/perl-Device-FTDI/issues>.
 
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012,2015 Pavel Shaydo.
+Copyright 2015 Paul "LeoNerd" Evans.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
